pub struct FastCache { /* private fields */ }Implementations
Sourceimpl FastCache
The update is slow, but the loading is more than 20 times faster than Moka’s cache.
impl FastCache
The update is slow, but the loading is more than 20 times faster than Moka’s cache.
pub fn new(size: u64, ttl: u64) -> FastCache
Sourcepub fn insert(
&self,
hash: u128,
value: Arc<dyn CacheVal>,
) -> Option<(u128, Arc<dyn CacheVal>)>
pub fn insert( &self, hash: u128, value: Arc<dyn CacheVal>, ) -> Option<(u128, Arc<dyn CacheVal>)>
Insert a value and return evicted data if it has a different hash value than the inserted one.
pub fn get(&self, hash: u128, now: u64, msec: MSec) -> Option<Arc<dyn CacheVal>>
pub fn invalidate(&self, hash: u128)
pub fn invalidate_all_of(&self, type_id: u64)
pub fn invalidate_all(&self)