Receiver

Struct Receiver 

pub struct Receiver<T> { /* private fields */ }

Implementations

Source

impl<T> Receiver<T>
where T: Decoder,

pub async fn recv(&mut self) -> Option<Option<Result<T>>>

Receive data from the Linker. If the connection with the Linker is disconnected, return None. If there is an abnormal disconnection between Linkers and it reconnects, return Some(None).